@@ -47,20 +47,8 @@ ResolutionSlider::ResolutionSlider(const KScreen::OutputPtr &output, QWidget *pa
 {
     connect(output.data(), &KScreen::Output::currentModeIdChanged,
             this, &ResolutionSlider::slotOutputModeChanged);
-    connect(output.data(), &KScreen::Output::modesChanged,
-            this, &ResolutionSlider::init);
 
-    init();
-}
-
-ResolutionSlider::~ResolutionSlider()
-{
-}
-
-void ResolutionSlider::init()
-{
-    mModes.clear();
-    Q_FOREACH (const KScreen::ModePtr &mode, mOutput->modes()) {
+    Q_FOREACH (const KScreen::ModePtr &mode, output->modes()) {
         if (mModes.contains(mode->size())) {
             continue;
         }
@@ -69,18 +57,6 @@ void ResolutionSlider::init()
     }
     qSort(mModes.begin(), mModes.end(), sizeLessThan);
 
-    delete layout();
-    delete mSmallestLabel;
-    mSmallestLabel = nullptr;
-    delete mBiggestLabel;
-    mBiggestLabel = nullptr;
-    delete mCurrentLabel;
-    mCurrentLabel = nullptr;
-    delete mSlider;
-    mSlider = nullptr;
-    delete mComboBox;
-    mComboBox = nullptr;
-
     QGridLayout *layout = new QGridLayout(this);
 
     if (mModes.count() > 15) {
@@ -90,22 +66,20 @@ void ResolutionSlider::init()
         mComboBox->setEditable(false);
         Q_FOREACH (const QSize &size, mModes) {
             mComboBox->addItem(Utils::sizeToString(size));
-            if ((mOutput->currentMode() && (mOutput->currentMode()->size() == size))
-                || (mOutput->preferredMode() && (mOutput->preferredMode()->size() == size))) {
+            if ((output->currentMode() && (output->currentMode()->size() == size))
+                || (output->preferredMode() && (output->preferredMode()->size() == size))) {
                     mComboBox->setCurrentIndex(mComboBox->count() - 1);
             }
         }
         layout->addWidget(mComboBox, 0, 0, 1, 1);
         connect(mComboBox, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
-                this, &ResolutionSlider::slotValueChanged, Qt::UniqueConnection);
-
-        Q_EMIT resolutionChanged(mModes.at(mComboBox->currentIndex()));
+                this, &ResolutionSlider::slotValueChanged);
     } else {
         mCurrentLabel = new QLabel(this);
         mCurrentLabel->setAlignment(Qt::AlignCenter);
         layout->addWidget(mCurrentLabel, 1, 0, 1, 3);
 
-        if (mModes.count() == 0) {
+        if (mModes.isEmpty()) {
             mCurrentLabel->setText(i18n("No available resolutions"));
         } else if (mModes.count() == 1) {
             mCurrentLabel->setText(Utils::sizeToString(mModes.first()));
@@ -118,10 +92,10 @@ void ResolutionSlider::init()
             mSlider->setMinimum(0);
             mSlider->setMaximum(mModes.size() - 1);
             mSlider->setSingleStep(1);
-            if (mOutput->currentMode()) {
-                mSlider->setValue(mModes.indexOf(mOutput->currentMode()->size()));
-            } else if (mOutput->preferredMode()) {
-                mSlider->setValue(mModes.indexOf(mOutput->preferredMode()->size()));
+            if (output->currentMode()) {
+                mSlider->setValue(mModes.indexOf(output->currentMode()->size()));
+            } else if (output->preferredMode()) {
+                mSlider->setValue(mModes.indexOf(output->preferredMode()->size()));
             } else {
                 mSlider->setValue(mSlider->maximum());
             }
@@ -136,13 +110,15 @@ void ResolutionSlider::init()
             mBiggestLabel->setText(Utils::sizeToString(mModes.last()));
             layout->addWidget(mBiggestLabel, 0, 2);
 
-            const auto size = mModes.at(mSlider->value());
-            mCurrentLabel->setText(Utils::sizeToString(size));
-            Q_EMIT resolutionChanged(size);
+            mCurrentLabel->setText(Utils::sizeToString(mModes.at(mSlider->value())));
         }
     }
 }
 
+ResolutionSlider::~ResolutionSlider()
+{
+}
+
 QSize ResolutionSlider::currentResolution() const
 {
     if (mModes.isEmpty()) {
